#ifndef NT2_INCLUDE_FUNCTIONS_RDIVIDE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RDIVIDE_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/rdivide.hpp>

#endif
